@@ -4,10 +4,11 @@ from __future__ import unicode_literals
 
 from datetime import timedelta
 import re
-from time import time, mktime
+from time import time
+from calendar import timegm
 
 from dateutil import relativedelta
-from dateutil.tz import tzlocal
+from dateutil.tz import tzutc
 
 from faker.generator import random
 from faker.utils.datetime_safe import date, datetime, real_date, real_datetime
@@ -20,8 +21,8 @@ localized = True
 
 def datetime_to_timestamp(dt):
     if getattr(dt, 'tzinfo', None) is not None:
-        dt = dt.astimezone(tzlocal())
-    return mktime(dt.timetuple())
+        dt = dt.astimezone(tzutc())
+    return timegm(dt.timetuple())
 
 
 timedelta_pattern = r''
@@ -360,6 +361,70 @@ class Provider(BaseProvider):
         timestamp = random.randint(start_date, end_date)
         return datetime.fromtimestamp(timestamp, tzinfo)
 
+    @classmethod
+    def future_datetime(cls, end_date='+30d', tzinfo=None):
+        """
+        Get a DateTime object based on a random date between 1 second form now
+        and a given date.
+        Accepts date strings that can be recognized by strtotime().
+
+        :param end_date Defaults to "+30d"
+        :param tzinfo: timezone, instance of datetime.tzinfo subclass
+        :example DateTime('1999-02-02 11:42:52')
+        :return DateTime
+        """
+        return cls.date_time_between(
+            start_date='+1s', end_date=end_date, tzinfo=tzinfo,
+        )
+
+    @classmethod
+    def future_date(cls, end_date='+30d', tzinfo=None):
+        """
+        Get a Date object based on a random date between 1 day from now and a
+        given date.
+        Accepts date strings that can be recognized by strtotime().
+
+        :param end_date Defaults to "+30d"
+        :param tzinfo: timezone, instance of datetime.tzinfo subclass
+        :example DateTime('1999-02-02 11:42:52')
+        :return DateTime
+        """
+        return cls.date_time_between(
+            start_date='+1d', end_date=end_date, tzinfo=tzinfo,
+        ).date()
+
+    @classmethod
+    def past_datetime(cls, start_date='-30d', tzinfo=None):
+        """
+        Get a DateTime object based on a random date between a given date and 1
+        second ago.
+        Accepts date strings that can be recognized by strtotime().
+
+        :param start_date Defaults to "-30d"
+        :param tzinfo: timezone, instance of datetime.tzinfo subclass
+        :example DateTime('1999-02-02 11:42:52')
+        :return DateTime
+        """
+        return cls.date_time_between(
+            start_date=start_date, end_date='-1s', tzinfo=tzinfo,
+        )
+
+    @classmethod
+    def past_date(cls, start_date='-30d', tzinfo=None):
+        """
+        Get a Date object based on a random date between a given date and 1 day
+        ago.
+        Accepts date strings that can be recognized by strtotime().
+
+        :param start_date Defaults to "-30d"
+        :param tzinfo: timezone, instance of datetime.tzinfo subclass
+        :example DateTime('1999-02-02 11:42:52')
+        :return DateTime
+        """
+        return cls.date_time_between(
+            start_date=start_date, end_date='-1d', tzinfo=tzinfo,
+        ).date()
+
     @classmethod
     def date_time_between_dates(cls, datetime_start=None, datetime_end=None, tzinfo=None):
         """
